==> charcoal-0.9.0.zip: charcoal-0.9.0/charcoal/charcoal.inc.php <==
<?php

// 桼ˤǤ̵뤹
ignore_user_abort( TRUE );

// 顼
error_reporting(E_ALL);

// 㳰ȥ졼
define( 'ENABLE_INTERNAL_EXCEPTION_TRACE', FALSE );

//==================================================================
// OSˤäƥѥڤʸȽ

if (!defined('PATH_SEPARATOR')) {
	if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
		define('PATH_SEPARATOR', ';');
	} else {
		define('PATH_SEPARATOR', ':');
	}
}

//==================================================================
// 

define( 'PROC_KEYWORD', 'proc' );

//==================================================================
// 󥯥롼ɥѥ

function add_include_path( $path )
{
	ini_set(
			'include_path', 
			ini_get('include_path') . PATH_SEPARATOR . $path
		);
}

ini_set( 'include_path', NULL );
add_include_path( CHARCOAL_HOME . '/classes/' );
add_include_path( WEBAPP_DIR . '/' . APPLICATION . '/classes/' );

//==================================================================
// autoload

function __autoload( $class_name )
{
	static $class_loader = false;
	if ( !$class_loader ){
		require ( 'core/ClassLoader.class.php' );
		$class_loader = true;
	}

//	require_once ( 'core/ClassLoader.class.php' );

	$loaded = ClassLoader::loadClass( $class_name );
}

//==================================================================
// ϴؿ

// TRACE
function log_trace( $logger_names, $message, $file, $line )
{
	Logger::writeln( "T:$logger_names", $message, $file, $line );
}

// INFO
function log_info( $logger_names, $message, $file, $line )
{
	Logger::writeln( "I:$logger_names", $message, $file, $line );
}

// WARNING
function log_warning( $logger_names, $message, $file, $line )
{
	Logger::writeln( "W:$logger_names", $message, $file, $line );
}

// DEBUG
function log_debug( $logger_names, $message, $file, $line )
{
	Logger::writeln( "D:$logger_names", $message, $file, $line );
}

// ERROR
function log_error( $logger_names, $message, $file, $line )
{
	Logger::writeln( "E:$logger_names", $message, $file, $line );
}

// FATAL
function log_fatal( $logger_names, $message, $file, $line )
{
	Logger::writeln( "F:$logger_names", $message, $file, $line );
}

//==================================================================
// 

function array_dump( $array, $title = NULL )
{
	print System::arrayToString($array,$title);
}

//==================================================================
// Ѵ
function boolval( $str )
{
	return ( $str === 'TRUE' || $str === 'on' || $str === '1' );
}

//==================================================================
// ץߥƥؿ

function s( $value, $encoding = NULL )
{
	if ( $value instanceof String ){
		return $value;
	}
	return $value !== NULL ? new String( $value, $encoding ) : new String( '', $encoding );
}

function i( $value )
{
	if ( $value instanceof Integer ){
		return $value;
	}
	return $value ? new Integer( $value ) : new Integer( 0 );
}

function b( $value )
{
	if ( $value instanceof Boolean ){
		return $value;
	}
	return $value ? new Boolean( $value ) : new Boolean( FALSE );
}

function v( $value )
{
	if ( $value instanceof Vector ){
		return $value;
	}
	return $value ? new Vector( $value ) : new Vector( array() );
}

//==================================================================
// HTMLϢؿ

function h( $str )
{
	return htmlspecialchars($str, ENT_QUOTES, mb_internal_encoding());
}

//==================================================================
// 㳰򥹥

function _throw( Exception $e )
{
	if ( ENABLE_INTERNAL_EXCEPTION_TRACE ){
		list( $file, $line ) = System::caller();
		$file = basename($file);
		$clazz = get_class($e);
		$id = $e->hashCode();
		$message = $e->getMessage();
		print "Throw $clazz ($id) $message @$file($line)<br>";
	}
	throw $e;
}

//==================================================================
// 㳰򥭥å
function _catch( Exception $e )
{
	if ( ENABLE_INTERNAL_EXCEPTION_TRACE ){
		list( $file, $line ) = System::caller();
		$file = basename($file);
		$clazz = get_class($e);
		$id = $e->hashCode();
		$message = $e->getMessage();
		print "Catched $clazz ($id) $message @$file($line)<br>";
	}
}

//==================================================================
// WEBAPPʲΥѥ
function _webapp_path( String $folder, String $filename = NULL )
{
	return ResourceLocator::getWebAppPath( $folder, $filename );
}

//==================================================================
// WEBAPPʲΥѥ
function _system_path( String $folder, String $filename = NULL )
{
	return ResourceLocator::getSystemPath( $folder, $filename );
}

//==================================================================
// ץեɤ߹

switch( CHARCOAL_RUNMODE ){
case 'http':
//	$host = gethostbyaddr($_SERVER["SERVER_ADDR"]);
	$host = $_SERVER["SERVER_NAME"];
	break;
case 'shell':
	$host = 'shell';
	break;
default:
	_throw( new UnexpectedRunModeException( CHARCOAL_RUNMODE ) );
	break;
}

Profile::load( $host );

// ॢȤ
$timeout = Profile::getInteger( s('SCRIPT_TIMEOUT') ,600);
set_time_limit( $timeout );

==> charcoal-0.11.0.zip: charcoal-0.11.0/charcoal/charcoal.inc.php <==
<?php

// 桼ˤǤ̵뤹
ignore_user_abort( TRUE );

// 顼
error_reporting(E_ALL);

// 㳰ȥ졼
define( 'ENABLE_INTERNAL_EXCEPTION_TRACE', FALSE );

//==================================================================
// OSˤäƥѥڤʸȽ

if (!defined('PATH_SEPARATOR')) {
	if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
		define('PATH_SEPARATOR', ';');
	} else {
		define('PATH_SEPARATOR', ':');
	}
}

//==================================================================
// 

define( 'PROC_KEYWORD', 'proc' );

//==================================================================
// 󥯥롼ɥѥ

function add_include_path( $path )
{
	ini_set(
			'include_path', 
			ini_get('include_path') . PATH_SEPARATOR . $path
		);
}

ini_set( 'include_path', NULL );
add_include_path( CHARCOAL_HOME . '/classes/' );
add_include_path( WEBAPP_DIR . '/' . APPLICATION . '/classes/' );

//==================================================================
// autoload

function __autoload( $class_name )
{
	static $class_loader = false;
	if ( !$class_loader ){
		require ( 'core/ClassLoader.class.php' );
		$class_loader = true;
	}

//	require_once ( 'core/ClassLoader.class.php' );

	$loaded = ClassLoader::loadClass( $class_name );
}

//==================================================================
// ϴؿ

// TRACE
function log_trace( $logger_names, $message )
{
	Logger::writeln( s("T:$logger_names"), s($message) );
}

// INFO
function log_info( $logger_names, $message )
{
	Logger::writeln( s("I:$logger_names"), s($message) );
}

// WARNING
function log_warning( $logger_names, $message )
{
	Logger::writeln( s("W:$logger_names"), s($message) );
}

// DEBUG
function log_debug( $logger_names, $message )
{
	Logger::writeln( s("D:$logger_names"), s($message) );
}

// ERROR
function log_error( $logger_names, $message )
{
	Logger::writeln( s("E:$logger_names"), s($message) );
}

// FATAL
function log_fatal( $logger_names, $message )
{
	Logger::writeln( s("F:$logger_names"), $message );
}

//==================================================================
// 

function array_dump( $array, $title = NULL )
{
	print System::arrayToString($array,$title);
}

//==================================================================
// Ѵ
function boolval( $str )
{
	return ( $str === 'TRUE' || $str === 'on' || $str === '1' );
}

//==================================================================
// ץߥƥؿ

function s( $value, $encoding = NULL )
{
	if ( $value instanceof String ){
		return $value;
	}
	return $value !== NULL ? new String( $value, $encoding ) : new String( '', $encoding );
}

function i( $value )
{
	if ( $value instanceof Integer ){
		return $value;
	}
	return $value ? new Integer( $value ) : new Integer( 0 );
}

function b( $value )
{
	if ( $value instanceof Boolean ){
		return $value;
	}
	return $value ? new Boolean( $value ) : new Boolean( FALSE );
}

function v( $value )
{
	if ( $value instanceof Vector ){
		return $value;
	}
	return $value ? new Vector( $value ) : new Vector( array() );
}

//==================================================================
// HTMLϢؿ

function h( $str )
{
	return htmlspecialchars($str, ENT_QUOTES, mb_internal_encoding());
}

//==================================================================
// 㳰򥹥

function _throw( Exception $e )
{
	if ( ENABLE_INTERNAL_EXCEPTION_TRACE ){
		list( $file, $line ) = System::caller();
		$file = basename($file);
		$clazz = get_class($e);
		$id = $e->hashCode();
		$message = $e->getMessage();
		print "Throw $clazz ($id) $message @$file($line)<br>";
	}
	throw $e;
}

//==================================================================
// 㳰򥭥å
function _catch( Exception $e )
{
	if ( ENABLE_INTERNAL_EXCEPTION_TRACE ){
		list( $file, $line ) = System::caller();
		$file = basename($file);
		$clazz = get_class($e);
		$id = $e->hashCode();
		$message = $e->getMessage();
		print "Catched $clazz ($id) $message @$file($line)<br>";
	}
}

//==================================================================
// WEBAPPʲΥѥ
function _webapp_path( String $folder, String $filename = NULL )
{
	return ResourceLocator::getWebAppPath( $folder, $filename );
}

//==================================================================
// WEBAPPʲΥѥ
function _system_path( String $folder, String $filename = NULL )
{
	return ResourceLocator::getSystemPath( $folder, $filename );
}

//==================================================================
// ץեɤ߹

switch( CHARCOAL_RUNMODE ){
case 'http':
//	$host = gethostbyaddr($_SERVER["SERVER_ADDR"]);
	$host = $_SERVER["SERVER_NAME"];
	break;
case 'shell':
	$host = 'shell';
	break;
default:
	_throw( new UnexpectedRunModeException( CHARCOAL_RUNMODE ) );
	break;
}

Profile::load( $host );

// ॢȤ
$timeout = Profile::getInteger( s('SCRIPT_TIMEOUT') ,600);
set_time_limit( $timeout );
